@@ -8,6 +8,9 @@ class TestClass(models.Model):
     field1 = models.TextField()
     field2 = models.TextField()
     field3 = models.CharField(max_length=100, blank=True)
+    bool_field = models.BooleanField(default=False)
+    int_field = models.IntegerField(default=0)
+    float_field = models.FloatField(default=0.0)
     
     other_field = models.CharField(max_length=100)
 
@@ -28,4 +31,8 @@ class TestClass(models.Model):
     
     def can_edit_object(self, user):
         return user.is_staff
+    
+    @property
+    def properties(self):
+        return {"abc": "ABC"}
 
