@@ -4,6 +4,22 @@ from django.contrib.sitemaps import Sitemap
 from coop_cms.settings import get_article_class
 from coop_cms.models import BaseArticle
 from django.conf import settings
+from django.contrib.sites.models import Site
+from django.core.urlresolvers import reverse
+
+class ViewSitemap(Sitemap):
+    view_names = []
+    
+    def items(self):
+        
+        class Klass(object):
+            def __init__(self, name):
+                self.name = name
+            
+            def get_absolute_url(self):
+                return reverse(self.name)
+            
+        return [Klass(x) for x in self.view_names]
 
 class ArticleSitemap(Sitemap):
     changefreq = "weekly"
@@ -11,7 +27,8 @@ class ArticleSitemap(Sitemap):
 
     def items(self):
         Article = get_article_class()
-        return Article.objects.filter(publication=BaseArticle.PUBLISHED)
+        return Article.objects.filter(
+            publication=BaseArticle.PUBLISHED, sites=Site.objects.get_current())
 
     def lastmod(self, obj):
         return obj.modified
@@ -31,5 +48,5 @@ def get_sitemaps(langs=None):
     return sitemaps
     
 urlpatterns = (
-    url(r'^sitemap\.xml$', 'django.contrib.sitemaps.views.sitemap', {'sitemaps': get_sitemaps()}),
+    url(r'^sitemap\.xml$', 'django.contrib.sitemaps.views.sitemap', {'sitemaps': get_sitemaps()}, name="coop_cms_sitemap"),
 )
\ No newline at end of file
